pub trait ResetDependencies {
// Required method
unsafe fn reset_dependencies(&self);
}Expand description
A trait for locks whose dynamic dependency tracking graph can be reset.
This should only be called when we need to change a previous lock ordering.
Required Methods
Sourceunsafe fn reset_dependencies(&self)
unsafe fn reset_dependencies(&self)
Resets the lock dependency graph for this lock.
Safety
It is the responsibility of the caller to ensure changing this lock ordering is safe.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".